Module credentials_module

Module credentials_module 

7. Credentials module

Module Identifier: credentials Type: Configuration Module The credentials module is used to exchange the credentials token that has to be used by parties for authorization of requests. Every OCPI request is required to contain a credentials token in the HTTP Authorization header.

Traits

CredentialsModule