ChargingPeriod

Struct ChargingPeriod 

pub struct ChargingPeriod {
    pub start_date_time: DateTime,
    pub dimensions: Vec<CdrDimension>,
    pub tariff_id: Option<CiString<36>>,
}

Fields

start_date_time: DateTime

Start timestamp of the charging period. A period ends when the next period starts. The last period ends when the session ends.

dimensions: Vec<CdrDimension>

List of relevant values for this charging period.

tariff_id: Option<CiString<36>>

Unique identifier of the Tariff that is relevant for this Charging Period. If not provided, no Tariff is relevant during this period.